﻿using CompositePlasticBag;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace CompositePlasticBagTests
{
    [TestClass]
    public class StuffContainerTests
    {
        private static readonly IStuff Milk = new OrdinaryStuff { Description = "Milk", Weight = 1000 };
        private static readonly IStuff Coffee = new OrdinaryStuff { Description = "Coffee", Weight = 500 };
        private static readonly IStuff Bread = new OrdinaryStuff { Description = "Bread", Weight = 600 };

        [TestMethod]
        public void AddTest()
        {
            StuffContainer plasticBag = new StuffContainer { Description = "plastic bag", MaxWeight = 5000 };
            Assert.IsTrue(plasticBag.IsEmpty);
            Assert.IsTrue(plasticBag.Add(Milk));
            Assert.IsTrue(plasticBag.Add(Coffee));
            Assert.AreEqual(1500, plasticBag.Weight);
            Assert.IsTrue(plasticBag.Add(Milk));
            Assert.IsTrue(plasticBag.Add(Milk));
            Assert.IsTrue(plasticBag.Add(Milk));
            Assert.AreEqual(4500, plasticBag.Weight);
            Assert.AreEqual(5, plasticBag.Count);
            Assert.IsFalse(plasticBag.Add(Milk));

            Assert.IsTrue(plasticBag.Remove(Milk));
            Assert.AreEqual(4, plasticBag.Count);
            Assert.AreEqual(3500, plasticBag.Weight);
        }

        [TestMethod]
        public void BagInBag()
        {
            StuffContainer plasticBag1 = new StuffContainer { Description = "plastic bag", MaxWeight = 4000 };
            plasticBag1.Add(Milk);
            plasticBag1.Add(Coffee);
            Assert.AreEqual(1500, plasticBag1.Weight);
            
            StuffContainer plasticBag2 = new StuffContainer { Description = "plastic bag 2", MaxWeight = 5000 };
            plasticBag2.Add(Bread);
            plasticBag2.Add(plasticBag1);
            Assert.AreEqual(2100, plasticBag2.Weight);
            Assert.AreEqual(3, plasticBag2.Count);

            Assert.IsTrue(plasticBag2.Contains(plasticBag1));

            Assert.IsTrue(plasticBag1.Contains(Milk));
            Assert.IsTrue(plasticBag1.Contains(Coffee));
            Assert.IsFalse(plasticBag1.Contains(Bread));

            Assert.IsTrue(plasticBag2.Contains(Bread));
            Assert.IsTrue(plasticBag2.Contains(Coffee));
            Assert.IsTrue(plasticBag2.Contains(Milk));
        }

        
    }
}
